"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Item = void 0;
const internal_1 = require("../internal");
class Item extends internal_1.State {
    /**
     * @public
     * Item of Collection
     * @param collection - Collection to which the Item belongs
     * @param data - Data that the Item holds
     * @param config - Config
     */
    constructor(collection, data, config = {}) {
        super(collection.agileInstance(), data, {
            isPlaceholder: config.isPlaceholder,
            key: data[collection.config.primaryKey],
        });
        this.isSelected = false; // If Item is selected by a Selector
        this.collection = () => collection;
        // Add rebuildGroupsThatIncludeItemKey to sideEffects to rebuild Groups that include this Item if it mutates
        this.addRebuildGroupThatIncludeItemKeySideEffect(this._key || 'unknown');
    }
    //=========================================================================================================
    // Set Key
    //=========================================================================================================
    /**
     * @internal
     * Updates Key/Name of State
     * @param value - New Key/Name of State
     * @param config - Config
     */
    setKey(value, config = {}) {
        super.setKey(value);
        config = internal_1.defineConfig(config, {
            sideEffects: {
                enabled: true,
                exclude: [],
            },
            background: false,
            force: false,
            storage: true,
            overwrite: false,
        });
        if (!value)
            return this;
        // Remove old rebuildGroupsThatIncludeItemKey sideEffect
        this.removeSideEffect(Item.updateGroupSideEffectKey);
        // Add rebuildGroupsThatIncludeItemKey to sideEffects to rebuild Groups that include this Item if it mutates
        this.addRebuildGroupThatIncludeItemKeySideEffect(value);
        // Update ItemKey in ItemValue (After updating the sideEffect because otherwise it calls the old sideEffect)
        this.patch({ [this.collection().config.primaryKey]: value }, {
            sideEffects: config.sideEffects,
            background: config.background,
            force: config.force,
            storage: config.storage,
            overwrite: config.overwrite,
        });
        return this;
    }
    //=========================================================================================================
    // Add Rebuild Group That Include ItemKey SideEffect
    //=========================================================================================================
    /**
     * @internal
     * Adds rebuildGroupThatIncludeItemKey to the Item sideEffects
     * @param itemKey - ItemKey at which the groups has to rebuild
     */
    addRebuildGroupThatIncludeItemKeySideEffect(itemKey) {
        this.addSideEffect(Item.updateGroupSideEffectKey, (instance, config) => instance.collection().rebuildGroupsThatIncludeItemKey(itemKey, config), { weight: 100 });
    }
}
exports.Item = Item;
Item.updateGroupSideEffectKey = 'rebuildGroup';
