import { State, Agile, Observer, Event, StateConfigInterface, Group, SideEffectConfigInterface } from '../internal';
export declare class Computed<ComputedValueType = any> extends State<ComputedValueType> {
    agileInstance: () => Agile;
    computeFunction: () => ComputedValueType;
    deps: Array<Observer>;
    hardCodedDeps: Array<Observer>;
    /**
     * @public
     * Computed - Function that recomputes its value if a dependency changes
     * @param agileInstance - An instance of Agile
     * @param computeFunction - Function for computing value
     * @param config - Config
     */
    constructor(agileInstance: Agile, computeFunction: () => ComputedValueType, config?: ComputedConfigInterface);
    /**
     * @public
     * Recomputes Value of Computed
     * @param config - Config
     */
    recompute(config?: RecomputeConfigInterface): void;
    /**
     * @public
     * Applies new compute Function to Computed
     * @param computeFunction - New Function for computing value
     * @param deps - Hard coded dependencies of Computed Function
     * @param config - Config
     */
    updateComputeFunction(computeFunction: () => ComputedValueType, deps?: Array<Observer | State | Event>, config?: UpdateComputeFunctionInterface): void;
    /**
     * @internal
     * Computes Value and adds missing Dependencies to Computed
     */
    computeValue(): ComputedValueType;
    /**
     * @internal
     * Gets Observer out of passed Instances
     * @param instances - Instances that hold an Observer
     */
    formatDeps(instances: Array<any>): Array<Observer>;
    patch(): this;
    persist(): this;
    invert(): this;
}
/**
 * @param computedDeps - Hard coded dependencies of Computed Function
 */
export interface ComputedConfigInterface extends StateConfigInterface {
    computedDeps?: Array<Observer | State | Event | Group>;
}
/**
 * @param background - If recomputing value happens in the background (-> not causing any rerender)
 * @param sideEffects - If Side Effects of Computed get executed
 */
export interface RecomputeConfigInterface {
    background?: boolean;
    sideEffects?: SideEffectConfigInterface;
}
/**
 * @param overwriteDeps - If old hardCoded deps get overwritten
 */
export interface UpdateComputeFunctionInterface extends RecomputeConfigInterface {
    overwriteDeps?: boolean;
}
