import { Agile, Observer, SubscriptionContainer, ComponentSubscriptionContainer, CallbackSubscriptionContainer, SubscriptionContainerKeyType } from '../../internal';
export declare class SubController {
    agileInstance: () => Agile;
    componentSubs: Set<ComponentSubscriptionContainer>;
    callbackSubs: Set<CallbackSubscriptionContainer>;
    mountedComponents: Set<any>;
    /**
     * @internal
     * SubController - Handles subscriptions to Components
     * @param agileInstance - An instance of Agile
     */
    constructor(agileInstance: Agile);
    /**
     * @internal
     * Subscribe with Object shaped Subscriptions
     * @param integrationInstance - Callback Function or Component
     * @param subs - Initial Subscription Object
     * @param key - Key/Name of SubscriptionContainer
     */
    subscribeWithSubsObject(integrationInstance: any, subs?: {
        [key: string]: Observer;
    }, key?: SubscriptionContainerKeyType): {
        subscriptionContainer: SubscriptionContainer;
        props: {
            [key: string]: Observer['value'];
        };
    };
    /**
     * @internal
     * Subscribe with Array shaped Subscriptions
     * @param integrationInstance - Callback Function or Component
     * @param subs - Initial Subscription Array
     * @param key - Key/Name of SubscriptionContainer
     */
    subscribeWithSubsArray(integrationInstance: any, subs?: Array<Observer>, key?: SubscriptionContainerKeyType): SubscriptionContainer;
    /**
     * @internal
     * Unsubscribes SubscriptionContainer(Component)
     * @param subscriptionInstance - SubscriptionContainer or Component that holds an SubscriptionContainer
     */
    unsubscribe(subscriptionInstance: any): void;
    /**
     * @internal
     * Registers SubscriptionContainer and decides weather integrationInstance is a callback or component based Subscription
     * @param integrationInstance - Callback Function or Component
     * @param subs - Initial Subscriptions
     * @param key - Key/Name of SubscriptionContainer
     */
    registerSubscription(integrationInstance: any, subs?: Array<Observer>, key?: SubscriptionContainerKeyType): SubscriptionContainer;
    /**
     * @internal
     * Registers Component based Subscription and applies SubscriptionContainer to Component.
     * If an instance called 'subscriptionContainers' exists in Component it will push the new SubscriptionContainer to this Array,
     * otherwise it creates a new Instance called 'subscriptionContainer' which holds the new  SubscriptionContainer
     * @param componentInstance - Component that got subscribed by Observer/s
     * @param subs - Initial Subscriptions
     * @param key - Key/Name of SubscriptionContainer
     */
    registerComponentSubscription(componentInstance: any, subs?: Array<Observer>, key?: SubscriptionContainerKeyType): ComponentSubscriptionContainer;
    /**
     * @internal
     * Registers Callback based Subscription
     * @param callbackFunction - Callback Function that causes rerender on Component which got subscribed by Observer/s
     * @param subs - Initial Subscriptions
     * @param key - Key/Name of SubscriptionContainer
     */
    registerCallbackSubscription(callbackFunction: () => void, subs?: Array<Observer>, key?: SubscriptionContainerKeyType): CallbackSubscriptionContainer;
    /**
     * @internal
     * Mounts Component based SubscriptionContainer
     * @param componentInstance - SubscriptionContainer(Component) that gets mounted
     */
    mount(componentInstance: any): void;
    /**
     * @internal
     * Unmounts Component based SubscriptionContainer
     * @param componentInstance - SubscriptionContainer(Component) that gets unmounted
     */
    unmount(componentInstance: any): void;
}
