import { Agile } from './internal';
/**
 * @internal
 * Creates a fresh copy of an Array/Object
 * https://www.samanthaming.com/tidbits/70-3-ways-to-clone-objects/
 * @param value - Array/Object that gets copied
 */
export declare function copy<T = any>(value: T): T;
/**
 * @internal
 * Checks if an value is a valid Object
 * https://stackoverflow.com/questions/12996871/why-does-typeof-array-with-objects-return-object-and-not-array
 * @param value - Value that is tested for its correctness
 */
export declare function isValidObject(value: any): boolean;
/**
 * @internal
 * Check if array1 contains all elements of array2
 * @param array1 - Array 1
 * @param array2 - Array 2
 */
export declare function includesArray<DataType = any>(array1: Array<DataType>, array2: Array<DataType>): boolean;
/**
 * @internal
 * Transforms Item/s to an Item Array
 * @param items - Item/s that gets transformed to an Array
 * @param config - Config
 */
export declare function normalizeArray<DataType = any>(items?: DataType | Array<DataType>, config?: {
    createUndefinedArray?: boolean;
}): Array<DataType>;
/**
 * @internal
 * Tries to get an Instance of Agile from provided Instance
 * If no agileInstance found it returns the global bound Agile Instance
 * @param instance - Instance that might hold an Agile Instance
 */
export declare function getAgileInstance(instance: any): Agile | undefined;
/**
 * @internal
 * Checks if value is a function
 * @param value - Value that gets tested if its a function
 */
export declare function isFunction(value: any): boolean;
/**
 * @internal
 * Checks if value is an async function
 * @param value - Value that gets tested if its an async function
 */
export declare function isAsyncFunction(value: any): boolean;
/**
 * @internal
 * Checks the correctness of an url
 * Resource: https://stackoverflow.com/questions/5717093/check-if-a-javascript-string-is-a-url
 * @param url - Url that gets tested for its correctness
 */
export declare function isValidUrl(url: string): boolean;
/**
 * @internal
 * Checks if value is valid JsonString
 * @param value - Value that gets checked
 */
export declare function isJsonString(value: any): boolean;
/**
 * @internal
 * Merges default values/properties into config object
 * @param config - Config object that receives default values
 * @param defaults - Default values object that gets merged into config object
 * @param overwriteUndefinedProperties - If undefined Properties in config gets overwritten by the default value
 */
export declare function defineConfig<ConfigInterface = Object>(config: ConfigInterface, defaults: Object, overwriteUndefinedProperties?: boolean): ConfigInterface;
/**
 * @internal
 * @param addNewProperties - Adds new properties to source Object
 */
export interface FlatMergeConfigInterface {
    addNewProperties?: boolean;
}
/**
 * @internal
 * Merges items into object, be aware that the merge will only happen at the top level of the object.
 * Initially it adds new properties of the changes object into the source object.
 * @param source - Source object
 * @param changes - Changes that get merged into the source object
 * @param config - Config
 */
export declare function flatMerge<DataType = Object>(source: DataType, changes: Object, config?: FlatMergeConfigInterface): DataType;
/**
 * @internal
 * Check if two values are equal
 * @param value1 - First Value
 * @param value2 - Second Value
 */
export declare function equal(value1: any, value2: any): boolean;
/**
 * @internal
 * Checks if two values aren't equal
 * @param value1 - First Value
 * @param value2 - Second Value
 */
export declare function notEqual(value1: any, value2: any): boolean;
/**
 * @internal
 * Generates random Id
 * @param length - Length of generated Id
 */
export declare function generateId(length?: number): string;
/**
 * @internal
 * Transforms Object to Array
 * @param object - Object that gets transformed
 */
export declare function createArrayFromObject<P = any>(object: {
    [key: string]: P;
}): Array<{
    key: string;
    instance: P;
}>;
/**
 * @internal
 * Clones a Class
 * @param instance - Instance of Class you want to clone
 */
export declare function clone<T = any>(instance: T): T;
/**
 * @internal
 * Binds passed Instance globally at passed Key
 * https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/globalThis
 * https://blog.logrocket.com/what-is-globalthis-why-use-it/
 * @param key - Key/Name of Instance
 * @param instance - Instance
 * @param overwrite - If already existing instance at passed Key gets overwritten
 */
export declare function globalBind(key: string, instance: any, overwrite?: boolean): boolean;
